@@ -1,19 +1,7 @@
-import json
-import random
-from copy import copy
-from typing import List
-from typing import Union
-
-import h5py
 import numpy as np
 from tensorflow.keras.utils import Sequence
 
-from sonusai import SonusAIError
-from sonusai.mixture import Segment
-from sonusai.mixture import convert_mixid_to_list
-from sonusai.mixture import get_feature_frames_in_mixture
-from sonusai.mixture import get_mixtures_from_mixid
-from sonusai.utils import reshape_inputs
+from sonusai.mixture import MixtureID
 
 
 class DataGenerator(Sequence):
@@ -21,13 +9,21 @@ class DataGenerator(Sequence):
 
     def __init__(self,
                  filename: str,
-                 mixid: Union[str, List[int]],
+                 mixid: MixtureID,
                  batch_size: int,
                  timesteps: int,
                  flatten: bool,
                  add1ch: bool,
                  shuffle: bool = False):
         """Initialization"""
+        import h5py
+
+        from sonusai import SonusAIError
+        from sonusai.mixture import Segment
+        from sonusai.mixture import convert_mixid_to_list
+        from sonusai.mixture import get_feature_frames_in_mixture
+        from sonusai.mixture import mixdb_from_json
+
         self.filename = filename
         self.mixid = mixid
         self.batch_size = batch_size
@@ -38,7 +34,7 @@ class DataGenerator(Sequence):
 
         try:
             self.file = h5py.File(self.filename, 'r')
-            self.mixdb = json.loads(self.file.attrs['mixdb'])
+            self.mixdb = mixdb_from_json(self.file.attrs['mixdb'])
             self.stride = self.file['feature'].shape[1]
             self.num_bands = self.file['feature'].shape[2]
             self.num_classes = self.file['truth_f'].shape[1]
@@ -49,7 +45,7 @@ class DataGenerator(Sequence):
 
         self.file_frame_segments = dict()
         for m in self.mixid:
-            self.file_frame_segments[m] = Segment(self.mixdb['mixtures'][m]['o_frame_offset'],
+            self.file_frame_segments[m] = Segment(self.mixdb.mixtures[m].o_frame_offset,
                                                   get_feature_frames_in_mixture(self.mixdb, m))
 
         self.mixtures = None
@@ -66,6 +62,9 @@ class DataGenerator(Sequence):
 
     def __getitem__(self, batch_index: int) -> (np.ndarray, np.ndarray):
         """Get one batch of data"""
+
+        from sonusai.utils import reshape_inputs
+
         feature = np.empty((self.frames_per_batch, self.stride, self.num_bands), dtype=np.single)
         truth = np.empty((self.frames_per_batch, self.num_classes), dtype=np.single)
         start = 0
@@ -85,15 +84,23 @@ class DataGenerator(Sequence):
 
     def on_epoch_end(self) -> None:
         """Modification of dataset between epochs"""
+        import random
+
         if self.shuffle:
             random.shuffle(self.mixid)
             self.initialize_mixtures()
 
     def _initialize_mixtures(self) -> None:
+        from copy import copy
+
+        from sonusai import SonusAIError
+        from sonusai.mixture import Segment
+        from sonusai.mixture import get_mixtures_from_mixid
+
         self.mixtures = get_mixtures_from_mixid(self.mixdb, self.mixid)
         self.mixture_frame_segments = [self.file_frame_segments[m] for m in self.mixid]
 
-        frames = sum([sub['samples'] for sub in self.mixtures]) // self.mixdb['feature_step_samples']
+        frames = sum([sub.samples for sub in self.mixtures]) // self.mixdb.feature_step_samples
         self.frames_per_batch = self.batch_size if self.timesteps == 0 else self.batch_size * self.timesteps
         self.total_batches = frames // self.frames_per_batch
 
