@@ -6,7 +6,7 @@ options:
     -h, --help
     -v, --verbose                   Be verbose.
     -d MIXDB, --mixdb MIXDB         Mixture database JSON file.
-    -i MIXID, --mixid MIXID         Mixture IDs JSON file.
+    -i MIXID, --mixid MIXID         Mixture ID(s) to generate and analyze. [default: *].
     -o OUTPUT, --output OUTPUT      Output HDF5 file.
     -t, --truth                     Save truth_t. [default: False].
     -s, --segsnr                    Save segsnr. [default: False].
@@ -15,8 +15,6 @@ Generate a SonusAI mixture file from a SonusAI mixture database.
 
 Inputs:
     MIXDB       A SonusAI mixture database JSON file.
-    MIXID       A JSON file containing a list of mixture IDs. The list should be named 'mixid'.
-                If no file is provided, then all mixtures in the database will be generated.
 
 Outputs:
     OUTPUT.h5   A SonusAI mixture HDF5 file. Contains:
@@ -241,7 +239,7 @@ def main():
     from sonusai.mixture import get_samples_in_mixture
     from sonusai.mixture import get_transform_frames_in_mixture
     from sonusai.mixture import load_mixdb
-    from sonusai.mixture import load_mixid
+    from sonusai.utils import expand_range
     from sonusai.utils import grouper
     from sonusai.utils import human_readable_size
     from sonusai.utils import seconds_to_hms
@@ -251,7 +249,7 @@ def main():
 
     verbose = args['--verbose']
     mixdb_name = args['--mixdb']
-    mixid_name = args['--mixid']
+    mixid = args['--mixid']
     output_name = args['--output']
     compute_segsnr = args['--segsnr']
     compute_truth = args['--truth']
@@ -268,7 +266,10 @@ def main():
 
     logger.info(f'\nLoad mixture database from {mixdb_name}')
     mixdb = load_mixdb(name=mixdb_name)
-    mixid = load_mixid(mixdb=mixdb, name=mixid_name)
+    if mixid == '*':
+        mixid = list(range(len(mixdb.mixtures)))
+    else:
+        mixid = expand_range(mixid)
 
     mixdb_out, total_samples = init(mixdb=mixdb,
                                     mixid=mixid,
