@@ -51,7 +51,8 @@ def truth_function(target_audio: np.ndarray,
     from pyaaware import SED
 
     from sonusai import SonusAIError
-    from sonusai.utils import int16_to_float
+    from sonusai.mixture.mapped_snr_f import calculate_mapped_snr_f
+    from sonusai.utils.int16_to_float import int16_to_float
 
     truth = np.zeros((len(target_audio), config['num_classes']), dtype=np.single)
     zero_based_indices = [x - 1 for x in config['index']]
@@ -137,13 +138,32 @@ def truth_function(target_audio: np.ndarray,
 
         return truth
 
-    elif config['function'] in ['energy_f', 'snr_f']:
+    elif config['function'] in ['energy_f', 'snr_f', 'mapped_snr_f']:
         if config['target_gain'] == 0:
             return truth
 
         target_fft = ForwardTransform(N=config['frame_size'] * 4, R=config['frame_size'])
         noise_fft = ForwardTransform(N=config['frame_size'] * 4, R=config['frame_size'])
 
+        snr_db_mean = None
+        snr_db_std = None
+        if config['function'] == 'mapped_snr_f':
+            if 'config' not in config:
+                raise SonusAIError('Truth function mapped SNR missing config')
+
+            parameters = ['snr_db_mean', 'snr_db_std']
+            for parameter in parameters:
+                if parameter not in config['config']:
+                    raise SonusAIError(f'Truth function mapped SNR config missing required parameter: {parameter}')
+
+            snr_db_mean = config['config']['snr_db_mean']
+            if len(snr_db_mean) != target_fft.bins:
+                raise SonusAIError(f'Truth function mapped SNR snr_db_mean does not have {target_fft.bins} elements')
+
+            snr_db_std = config['config']['snr_db_std']
+            if len(snr_db_std) != target_fft.bins:
+                raise SonusAIError(f'Truth function mapped SNR snr_db_std does not have {target_fft.bins} elements')
+
         for index in zero_based_indices:
             if index + target_fft.bins > config['num_classes']:
                 raise SonusAIError('Truth index exceeds the number of classes')
@@ -151,7 +171,7 @@ def truth_function(target_audio: np.ndarray,
         for offset in range(0, len(target_audio), config['frame_size']):
             target_energy = np.single(
                 target_fft.energy_f(int16_to_float(target_audio[offset:offset + config['frame_size']])))
-            if config['function'] == 'snr_f':
+            if config['function'] in ['snr_f', 'mapped_snr_f']:
                 noise_energy = np.single(
                     noise_fft.energy_f(int16_to_float(noise_audio[offset:offset + config['frame_size']])))
             else:
@@ -159,9 +179,16 @@ def truth_function(target_audio: np.ndarray,
 
             indices = slice(offset, offset + config['frame_size'])
             for index in zero_based_indices:
-                truth[indices, index:index + target_fft.bins] = np.divide(target_energy, noise_energy,
-                                                                          out=np.ones(target_energy.shape) * np.inf,
-                                                                          where=noise_energy != 0)
+                old_err = np.seterr(divide='ignore', invalid='ignore')
+                tmp = target_energy / noise_energy
+                np.seterr(**old_err)
+
+                tmp = np.nan_to_num(tmp, nan=-np.inf, posinf=np.inf, neginf=-np.inf)
+
+                if config['function'] == 'mapped_snr_f':
+                    tmp = calculate_mapped_snr_f(tmp, snr_db_mean, snr_db_std)
+
+                truth[indices, index:index + target_fft.bins] = tmp
 
         return truth
 
@@ -177,7 +204,7 @@ def truth_function(target_audio: np.ndarray,
 def get_truth_indices_for_mixid(mixdb: MixtureDatabase, mixid: int) -> List[int]:
     """Get a list of truth indices for a given mixid."""
 
-    from sonusai.mixture import get_truth_indices_for_target
+    from sonusai.mixture.targets import get_truth_indices_for_target
 
     indices = list()
     for target_file_index in mixdb.mixtures[mixid].target_file_index:
