@@ -5,7 +5,6 @@ from sonusai.utils.dataclass_from_dict import dataclass_from_dict
 from sonusai.utils.dbfs import dbfs_to_sample
 from sonusai.utils.dbfs import sample_to_dbfs
 from sonusai.utils.engineering_number import EngineeringNumber
-from sonusai.utils.expand_range import expand_range
 from sonusai.utils.get_label_names import get_label_names
 from sonusai.utils.grouper import grouper
 from sonusai.utils.human_readable_size import human_readable_size
@@ -21,6 +20,8 @@ from sonusai.utils.parallel_tqdm import p_tqdm_map
 from sonusai.utils.parallel_tqdm import p_tqdm_umap
 from sonusai.utils.print_mixture_details import print_class_count
 from sonusai.utils.print_mixture_details import print_mixture_details
+from sonusai.utils.ranges import consolidate_range
+from sonusai.utils.ranges import expand_range
 from sonusai.utils.read_mixture_data import read_mixture_data
 from sonusai.utils.read_predict_data import read_predict_data
 from sonusai.utils.reshape import reshape_inputs
